import React, { Suspense } from 'react';
import { BrowserRouter as Router, Routes, Route, Navigate } from 'react-router-dom';
import Header from './components/Header';
import LoadingSpinner from './components/LoadingSpinner';
import { useMembershipStore } from './stores/membershipStore';

// Direct imports for all pages
import Home from './pages/Home';
import About from './pages/About';
import Events from './pages/Events';
import EventDetail from './pages/EventDetail';
import NewsDetail from './pages/NewsDetail';
import Resources from './pages/Resources';
import Contact from './pages/Contact';
import Shop from './pages/Shop';
import MemberPortal from './pages/MemberPortal';
import NotFound from './pages/NotFound';
import MembershipSuccess from './pages/MembershipSuccess';
import MembershipCancel from './pages/MembershipCancel';

function App() {
  const { isMember } = useMembershipStore();

  return (
    <Router>
      <div className="min-h-screen bg-white">
        <Header />
        <Suspense fallback={<LoadingSpinner />}>
          <Routes>
            <Route path="/" element={<Home />} />
            <Route path="/about" element={<About />} />
            <Route path="/events" element={<Events />} />
            <Route path="/events/:id" element={<EventDetail />} />
            <Route path="/news/:id" element={<NewsDetail />} />
            <Route path="/shop" element={<Shop />} />
            <Route path="/resources" element={<Resources />} />
            <Route path="/contact" element={<Contact />} />
            
            {/* Protected Routes */}
            <Route
              path="/member/*"
              element={
                isMember ? (
                  <Routes>
                    <Route path="/" element={<MemberPortal />} />
                    <Route path="profile" element={<MemberPortal />} />
                    <Route path="settings" element={<MemberPortal />} />
                  </Routes>
                ) : (
                  <Navigate to="/" replace />
                )
              }
            />

            {/* Membership Routes */}
            <Route path="/membership/success" element={<MembershipSuccess />} />
            <Route path="/membership/cancel" element={<MembershipCancel />} />

            {/* 404 Route */}
            <Route path="*" element={<NotFound />} />
          </Routes>
        </Suspense>
        <footer className="bg-c64a27 text-white py-8">
          <div className="container mx-auto px-4">
            <div className="grid md:grid-cols-3 gap-8">
              <div>
                <h3 className="text-xl font-bold mb-4">Contact Us</h3>
                <p>Email: psysoc@guild.uwa.edu.au</p>
                <p>Location: UWA Psychology Building</p>
              </div>
              <div>
                <h3 className="text-xl font-bold mb-4">Quick Links</h3>
                <ul className="space-y-2">
                  <li><a href="/about" className="hover:text-f1aa2f transition-colors">About Us</a></li>
                  <li><a href="/events" className="hover:text-f1aa2f transition-colors">Events</a></li>
                  <li><a href="/shop" className="hover:text-f1aa2f transition-colors">Shop</a></li>
                  <li><a href="/resources" className="hover:text-f1aa2f transition-colors">Resources</a></li>
                  <li><a href="/contact" className="hover:text-f1aa2f transition-colors">Contact</a></li>
                </ul>
              </div>
              <div>
                <h3 className="text-xl font-bold mb-4">Follow Us</h3>
                <div className="flex space-x-4">
                  <a href="https://www.facebook.com/UWAPsySoc" className="hover:text-f1aa2f transition-colors">Facebook</a>
                  <a href="https://www.instagram.com/psysocuwa/" className="hover:text-f1aa2f transition-colors">Instagram</a>
                  <a href="#" className="hover:text-f1aa2f transition-colors">Discord</a>
                </div>
              </div>
            </div>
            <div className="mt-8 pt-8 border-t border-white/20">
              <p className="text-center text-white/90 mb-4">
                The University of Western Australia Psychological Society acknowledges that it is situated on Noongar land, and that Noongar people remain the spiritual and cultural custodians of their land, and continue to practise their values, languages, beliefs and knowledge. 🖤❤️💛
              </p>
              <p className="text-center">&copy; {new Date().getFullYear()} UWA Psychological Society. All rights reserved.</p>
            </div>
          </div>
        </footer>
      </div>
    </Router>
  );
}

export default App;